private
function GetBB:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetBBB:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetBBG:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetBBR:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetBG:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetBGB:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetBGG:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetBGR:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetBR:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetBRB:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetBRG:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetBRR:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetGB:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetGBB:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetGBG:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetGBR:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetGG:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetGGB:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetGGG:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetGGR:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetGR:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetGRB:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetGRG:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetGRR:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetPP:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetPPP:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetPPS:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetPPT:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetPS:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetPSP:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetPSS:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetPST:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetPT:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetPTP:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetPTS:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetPTT:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetRB:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetRBB:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetRBG:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetRBR:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetRG:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetRGB:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetRGG:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetRGR:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetRR:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetRRB:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetRRG:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetRRR:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetSP:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetSPP:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetSPS:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetSPT:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetSS:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetSSP:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetSSS:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetSST:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetST:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetSTP:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetSTS:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetSTT:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetTP:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetTPP:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetTPS:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetTPT:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetTS:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetTSP:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetTSS:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetTST:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetTT:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetTTP:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetTTS:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetTTT:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetXX:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetXXX:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetXXY:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetXXZ:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetXY:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetXYX:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetXYY:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetXYZ:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetXZ:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetXZX:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetXZY:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetXZZ:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetYX:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetYXX:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetYXY:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetYXZ:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetYY:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetYYX:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetYYY:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetYYZ:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetYZ:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetYZX:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetYZY:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetYZZ:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetZX:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetZXX:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetZXY:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetZXZ:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetZY:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetZYX:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetZYY:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetZYZ:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetZZ:TpvVector2; {$ifdef CAN_INLINE}inline;{$endif}
function GetZZX:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetZZY:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
function GetZZZ:TpvVector3; {$ifdef CAN_INLINE}inline;{$endif}
procedure SetBG(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetBGR(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetBR(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetBRG(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetGB(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetGBR(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetGR(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetGRB(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetPS(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetPST(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetPT(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetPTS(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetRB(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetRBG(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetRG(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetRGB(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetSP(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetSPT(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetST(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetSTP(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetTP(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetTPS(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetTS(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetTSP(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetXY(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetXYZ(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetXZ(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetXZY(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetYX(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetYXZ(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetYZ(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetYZX(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetZX(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetZXY(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetZY(const pValue:TpvVector2); {$ifdef CAN_INLINE}inline;{$endif}
procedure SetZYX(const pValue:TpvVector3); {$ifdef CAN_INLINE}inline;{$endif}
public
property bb:TpvVector2 read GetBB;
property bbb:TpvVector3 read GetBBB;
property bbg:TpvVector3 read GetBBG;
property bbr:TpvVector3 read GetBBR;
property bg:TpvVector2 read GetBG write SetBG;
property bgb:TpvVector3 read GetBGB;
property bgg:TpvVector3 read GetBGG;
property bgr:TpvVector3 read GetBGR write SetBGR;
property br:TpvVector2 read GetBR write SetBR;
property brb:TpvVector3 read GetBRB;
property brg:TpvVector3 read GetBRG write SetBRG;
property brr:TpvVector3 read GetBRR;
property gb:TpvVector2 read GetGB write SetGB;
property gbb:TpvVector3 read GetGBB;
property gbg:TpvVector3 read GetGBG;
property gbr:TpvVector3 read GetGBR write SetGBR;
property gg:TpvVector2 read GetGG;
property ggb:TpvVector3 read GetGGB;
property ggg:TpvVector3 read GetGGG;
property ggr:TpvVector3 read GetGGR;
property gr:TpvVector2 read GetGR write SetGR;
property grb:TpvVector3 read GetGRB write SetGRB;
property grg:TpvVector3 read GetGRG;
property grr:TpvVector3 read GetGRR;
property pp:TpvVector2 read GetPP;
property ppp:TpvVector3 read GetPPP;
property pps:TpvVector3 read GetPPS;
property ppt:TpvVector3 read GetPPT;
property ps:TpvVector2 read GetPS write SetPS;
property psp:TpvVector3 read GetPSP;
property pss:TpvVector3 read GetPSS;
property pst:TpvVector3 read GetPST write SetPST;
property pt:TpvVector2 read GetPT write SetPT;
property ptp:TpvVector3 read GetPTP;
property pts:TpvVector3 read GetPTS write SetPTS;
property ptt:TpvVector3 read GetPTT;
property rb:TpvVector2 read GetRB write SetRB;
property rbb:TpvVector3 read GetRBB;
property rbg:TpvVector3 read GetRBG write SetRBG;
property rbr:TpvVector3 read GetRBR;
property rg:TpvVector2 read GetRG write SetRG;
property rgb:TpvVector3 read GetRGB write SetRGB;
property rgg:TpvVector3 read GetRGG;
property rgr:TpvVector3 read GetRGR;
property rr:TpvVector2 read GetRR;
property rrb:TpvVector3 read GetRRB;
property rrg:TpvVector3 read GetRRG;
property rrr:TpvVector3 read GetRRR;
property sp:TpvVector2 read GetSP write SetSP;
property spp:TpvVector3 read GetSPP;
property sps:TpvVector3 read GetSPS;
property spt:TpvVector3 read GetSPT write SetSPT;
property ss:TpvVector2 read GetSS;
property ssp:TpvVector3 read GetSSP;
property sss:TpvVector3 read GetSSS;
property sst:TpvVector3 read GetSST;
property st:TpvVector2 read GetST write SetST;
property stp:TpvVector3 read GetSTP write SetSTP;
property sts:TpvVector3 read GetSTS;
property stt:TpvVector3 read GetSTT;
property tp:TpvVector2 read GetTP write SetTP;
property tpp:TpvVector3 read GetTPP;
property tps:TpvVector3 read GetTPS write SetTPS;
property tpt:TpvVector3 read GetTPT;
property ts:TpvVector2 read GetTS write SetTS;
property tsp:TpvVector3 read GetTSP write SetTSP;
property tss:TpvVector3 read GetTSS;
property tst:TpvVector3 read GetTST;
property tt:TpvVector2 read GetTT;
property ttp:TpvVector3 read GetTTP;
property tts:TpvVector3 read GetTTS;
property ttt:TpvVector3 read GetTTT;
property xx:TpvVector2 read GetXX;
property xxx:TpvVector3 read GetXXX;
property xxy:TpvVector3 read GetXXY;
property xxz:TpvVector3 read GetXXZ;
property xy:TpvVector2 read GetXY write SetXY;
property xyx:TpvVector3 read GetXYX;
property xyy:TpvVector3 read GetXYY;
property xyz:TpvVector3 read GetXYZ write SetXYZ;
property xz:TpvVector2 read GetXZ write SetXZ;
property xzx:TpvVector3 read GetXZX;
property xzy:TpvVector3 read GetXZY write SetXZY;
property xzz:TpvVector3 read GetXZZ;
property yx:TpvVector2 read GetYX write SetYX;
property yxx:TpvVector3 read GetYXX;
property yxy:TpvVector3 read GetYXY;
property yxz:TpvVector3 read GetYXZ write SetYXZ;
property yy:TpvVector2 read GetYY;
property yyx:TpvVector3 read GetYYX;
property yyy:TpvVector3 read GetYYY;
property yyz:TpvVector3 read GetYYZ;
property yz:TpvVector2 read GetYZ write SetYZ;
property yzx:TpvVector3 read GetYZX write SetYZX;
property yzy:TpvVector3 read GetYZY;
property yzz:TpvVector3 read GetYZZ;
property zx:TpvVector2 read GetZX write SetZX;
property zxx:TpvVector3 read GetZXX;
property zxy:TpvVector3 read GetZXY write SetZXY;
property zxz:TpvVector3 read GetZXZ;
property zy:TpvVector2 read GetZY write SetZY;
property zyx:TpvVector3 read GetZYX write SetZYX;
property zyy:TpvVector3 read GetZYY;
property zyz:TpvVector3 read GetZYZ;
property zz:TpvVector2 read GetZZ;
property zzx:TpvVector3 read GetZZX;
property zzy:TpvVector3 read GetZZY;
property zzz:TpvVector3 read GetZZZ;
